@@ -1,4 +1,5 @@
-simu.Frank=function(n,alpha,scale1=1,scale2=1,shape1=1,shape2=1){
+simu.Frank=function(n,alpha,scale1=1,scale2=1,shape1=1,shape2=1,
+                    Print=FALSE){
   if((0<=alpha)&(alpha<0.0001)){alpha=0.0001}
   if((0>alpha)&(-0.0001<alpha)){alpha=-0.0001}
 
@@ -15,8 +16,12 @@ simu.Frank=function(n,alpha,scale1=1,scale2=1,shape1=1,shape2=1){
     Y.vec[i]=(-log(V)/scale2)^(1/shape2)
   }
 
-  func1=function(x){x/(exp(x)-1)}
-  Tau=1-4/alpha*(1-integrate(func1,0,alpha)$value/alpha)
-  print(c(true_Kendall_tau=round(Tau,3)))
+  if(Print==TRUE){
+    meanX=scale1^(-1/shape1)*gamma(1+1/shape1)
+    meanY=scale2^(-1/shape2)*gamma(1+1/shape2)
+    func1=function(x){x/(exp(x)-1)}
+    Tau=1-4/alpha*(1-integrate(func1,0,alpha)$value/alpha)
+    print(c(true_Kendall_tau=Tau,meanX=meanX,meanY=meanY))
+  }
   cbind(U=U.vec,V=V.vec,X=X.vec,Y=Y.vec)
 }
